var searchData=
[
  ['manager_0',['Netjack2 manager',['../page_module_netjack2_manager.html',1,'page_modules']]],
  ['manager_1',['Manager',['../page_session_manager.html',1,'PipeWire Session Manager'],['../page_module_session_manager.html',1,'Session Manager']]],
  ['metadata_2',['Metadata',['../page_module_metadata.html',1,'page_modules']]],
  ['metadata_3',['pw-metadata',['../page_man_pw-metadata_1.html',1,'page_programs']]],
  ['midi_20support_4',['MIDI Support',['../page_midi.html',1,'page_internals']]],
  ['mididump_5',['pw-mididump',['../page_man_pw-mididump_1.html',1,'page_programs']]],
  ['modules_6',['libpipewire-modules',['../page_man_libpipewire-modules_7.html',1,'page_config']]],
  ['modules_7',['Modules',['../page_modules.html',1,'']]],
  ['modules_8',['pipewire-pulse-modules',['../page_man_pipewire-pulse-modules_7.html',1,'page_config']]],
  ['modules_9',['Pulseaudio Modules',['../page_pulse_modules.html',1,'']]],
  ['mon_10',['pw-mon',['../page_man_pw-mon_1.html',1,'page_programs']]],
  ['monitor_11',['spa-monitor',['../page_man_spa-monitor_1.html',1,'page_programs']]]
];
